<?php
require_once(WCF_DIR.'lib/acp/form/DynamicOptionListForm.class.php');
require_once(WCF_DIR.'lib/acp/option/Options.class.php');

/**
 * Shows the option edit form.
 *
 * @package	com.woltlab.wcf.acp.form
 * @author	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class OptionForm extends DynamicOptionListForm {
	public $templateName = 'option';
	
	public $category;
	public $categoryID = 0;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['categoryID'])) $this->categoryID = intval($_REQUEST['categoryID']);
		
		// get option category
		$this->getOptionCategory();
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		
		// save options
		$saveOptions = array();
		foreach ($this->cachedOptions as $option) {
			$saveOptions[$option['optionID']] = $option['optionValue'];
		}
		Options::save($saveOptions);
		
		// clear cache
		Options::resetCache();
		
		// delete relevant options.inc.php's
		Options::resetFile();
		$this->saved();
		
		// show succes message
		WCF::getTPL()->assign('success', true);
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'category' => $this->category,
			'options' => $this->getOptionTree($this->category['categoryName'])
		));
	}
	
	/**
	 * @see Form::show()
	 */
	public function show() {
		// set active menu item
		WCFACP::getMenu()->setActiveMenuItem('wcf.acp.option.category.'.$this->category['categoryName']);
		
		// check permission
		WCF::getUser()->checkPermission('admin.system.canEditOption');
				
		// get options and categories from cache
		$this->readCache();
		
		// show form
		parent::show();
	}
	
	/**
	 * Gets the active option category.
	 */
	protected function getOptionCategory() {
		$sql = "SELECT	*
			FROM	wcf".WCF_N."_option_category
			WHERE	categoryID = ".$this->categoryID."
				AND parentCategoryName = ''";
		$this->category = WCF::getDB()->getFirstRow($sql);
		if (!isset($this->category['categoryID'])) {
			require_once(WCF_DIR.'lib/system/exception/IllegalLinkException.class.php');
			throw new IllegalLinkException();
		}
		
		$this->activeCategory = $this->category['categoryName'];
	}
	
	/**
	 * @see DynamicOptionListForm::checkOption()
	 */
	protected function checkOption($optionName) {
		$option = $this->cachedOptions[$optionName];
		return ($option['hidden'] != 1);
	}
}
?>