<?php
require_once(WCF_DIR.'lib/page/SortablePage.class.php');
require_once(WCF_DIR.'lib/data/user/group/Group.class.php');
require_once(WCF_DIR.'lib/system/event/EventHandler.class.php');

/**
 * Shows the result of an user search.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.acp.page
 */
class UserListPage extends SortablePage {
	public $searchID = 0;
	public $itemsPerPage = 50;
	public $defaultSortField = 'username';
	public $templateName = 'userList';
	public $userIDs = array();
	public $markedUsers = array();
	public $users = array();
	public $url = '';
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['searchID'])) {
			$this->searchID = intval($_REQUEST['searchID']);
			if ($this->searchID) $this->readSearchResult();
		}
	}
	
	/**
	 * @see SortablePage::validateSortField()
	 */
	public function validateSortField() {
		parent::validateSortField();
		
		switch ($this->sortField) {
			case 'email':
			case 'userID':
			case 'registrationDate':
			case 'username': break;
			default: $this->sortField = $this->defaultSortField;
		}
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		// get marked users
		$this->markedUsers = WCF::getSession()->getVar('markedUsers');
		if ($this->markedUsers == null || !is_array($this->markedUsers)) $this->markedUsers = array();
		
		$this->readUsers();
		
		// build page url
		$this->url = 'index.php?page=UserList&searchID='.$this->searchID.'&pageNo='.$this->pageNo.'&sortField='.$this->sortField.'&sortOrder='.$this->sortOrder.'&packageID='.PACKAGE_ID.SID_ARG_2ND_NOT_ENCODED;
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'users' => $this->users,
			'searchID' => $this->searchID,
			'markedUsers' => count($this->markedUsers),
			'url' => $this->url
		));
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		// set active menu item
		WCFACP::getMenu()->setActiveMenuItem('wcf.acp.menu.link.user.'.($this->searchID ? 'search' : 'list'));
		
		// check permission
		WCF::getUser()->checkPermission('admin.user.canSearchUser');
		
		parent::show();
	}
	
	/**
	 * @see MultipleLinkPage::countItems()
	 */
	public function countItems() {
		parent::countItems();

		// count users
		if ($this->searchID) {
			$userIDs = implode(',', $this->userIDs);
			if (empty($userIDs)) {
				require_once(WCF_DIR.'lib/system/exception/IllegalLinkException.class.php');
				throw new IllegalLinkException();
			}
			
			$sql = "SELECT	COUNT(*) AS count
				FROM	wcf".WCF_N."_user user
				WHERE	userID IN (".$userIDs.")";
			$row = WCF::getDB()->getFirstRow($sql);
			if (!$row['count']) {
				require_once(WCF_DIR.'lib/system/exception/IllegalLinkException.class.php');
				throw new IllegalLinkException();
			}
		}
		else {
			$sql = "SELECT	COUNT(*) AS count
				FROM	wcf".WCF_N."_user";
			$row = WCF::getDB()->getFirstRow($sql);
		}
		
		return $row['count'];
	}
	
	/**
	 * Gets the list of results.
	 */
	protected function readUsers() {
		// get user ids
		$userIDs = '';
		$sql = "SELECT		user.userID
			FROM		wcf".WCF_N."_user user
			".($this->searchID ? "WHERE user.userID IN (".implode(',', $this->userIDs).")" : '')."
			ORDER BY	user.".$this->sortField." ".$this->sortOrder;
		$result = WCF::getDB()->sendQuery($sql, $this->itemsPerPage, ($this->pageNo - 1) * $this->itemsPerPage);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$userIDs[] = $row['userID'];
		}

		// get user data
		$sql = "SELECT		option_value.*, user.*,
					GROUP_CONCAT(groupID SEPARATOR ',') AS groupIDs
			FROM		wcf".WCF_N."_user user
			LEFT JOIN	wcf".WCF_N."_user_option_value option_value
			ON		(option_value.userID = user.userID)
			LEFT JOIN	wcf".WCF_N."_user_to_groups groups
			ON		(groups.userID = user.userID)
			WHERE		user.userID IN (".implode(',', $userIDs).")
			GROUP BY	user.userID
			ORDER BY	user.".$this->sortField." ".$this->sortOrder;
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$accessible = Group::isAccessibleGroup(explode(',', $row['groupIDs']));
			$row['accessible'] = $accessible;
			$row['deletable'] = ($accessible && WCF::getUser()->getPermission('admin.user.canDeleteUser') && $row['userID'] != WCF::getUser()->userID) ? 1 : 0;
			$row['editable'] = ($accessible && WCF::getUser()->getPermission('admin.user.canEditUser')) ? 1 : 0;
			$row['isMarked'] = intval(in_array($row['userID'], $this->markedUsers));
			
			$this->users[] = $row;
		}
	}
	
	/**
	 * Gets the result of the search with the given search id.
	 */
	protected function readSearchResult() {
		// get user search from database
		$sql = "SELECT	searchData
			FROM	wcf".WCF_N."_search
			WHERE	searchID = ".$this->searchID."
				AND userID = ".WCF::getUser()->userID."
				AND searchType = 'users'";
		$search = WCF::getDB()->getFirstRow($sql);
		if (!isset($search['searchData'])) {
			require_once(WCF_DIR.'lib/system/exception/IllegalLinkException.class.php');
			throw new IllegalLinkException();
		}
		
		$data = unserialize($search['searchData']);
		$this->userIDs = $data['matches'];
		unset($data);
	}
}
?>