<?php
// imports
require_once(WCF_DIR.'lib/system/session/CookieSession.class.php');
require_once(WCF_DIR.'lib/system/session/SessionFactory.class.php');
require_once(WCF_DIR.'lib/data/user/User.class.php');

/**
 * CookieSessionFactory extends SessionFactory by cookie support.
 * 
 * @package	com.woltlab.wcf.system.session
 * @author	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class CookieSessionFactory extends SessionFactory {
	protected $sessionClassName = 'CookieSession';
	
	/**
	 * Classname used for guest sessions.
	 * 
	 * @var string
	 */
	protected $guestClassName = 'UserSession';
	
	/**
	 * @see SessionFactory::create()
	 */
	public function create() {
		// create new session hash
		$sessionID = StringUtil::getRandomID();
		
		// check cookies for userID & password
		require_once(WCF_DIR.'lib/system/auth/UserAuth.class.php');
		$user = UserAuth::getInstance()->loginAutomatically(true, $this->userClassName);
		
		if ($user === null) {
			// no valid user found
			// create guest user
			$user = new $this->guestClassName();
		}
		
		// update user session
		$user->update();
		
		// get spider information
		$spider = $this->isSpider(UserUtil::getUserAgent());		
		
		if ($user->userID != 0) {
			// user is no guest
			// delete all other sessions of this user
			$sql = "DELETE FROM 	wcf".WCF_N."_session
				WHERE 		userID = ".$user->userID;
			WCF::getDB()->sendQuery($sql);
		}
		$requestMethod = (!empty($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '');
		// insert session into database
		$serializedUserData = serialize($user);
		$sql = "INSERT INTO 	wcf".WCF_N."_session
					(sessionID, packageID, userID, ipAddress, userAgent,
					lastActivityTime, requestURI, requestMethod, userData, sessionVariables,
					username".($spider ? ", spiderID" : "").")
			VALUES		('".$sessionID."',
					".PACKAGE_ID.",
					".$user->userID.",
					'".escapeString(UserUtil::getIpAddress())."',
					'".escapeString(UserUtil::getUserAgent())."',
					".TIME_NOW.",
					'".escapeString(UserUtil::getRequestURI())."',
					'".escapeString($requestMethod)."',
					'".escapeString($serializedUserData)."',
					'',
					'".($spider ? escapeString($spider['spiderName']) : escapeString($user->username))."'
					".($spider ? ", ".$spider['spiderID'] : "").")";
		WCF::getDB()->sendQuery($sql);
		
		// return new session object
		return new $this->sessionClassName(null, array(
			'sessionID' => $sessionID,
			'packageID' => PACKAGE_ID,
			'userID' => $user->userID,
			'ipAddress' => UserUtil::getIpAddress(),
			'userAgent' =>  UserUtil::getUserAgent(),
			'lastActivityTime' => TIME_NOW,
			'requestURI' => UserUtil::getRequestURI(),
			'requestMethod' => $requestMethod,
			'userData' => $serializedUserData,
			'sessionVariables' => '',
			'username' => ($spider ? $spider['spiderName'] : $user->username),
			'spiderID' => ($spider ? $spider['spiderID'] : 0),
			'isNew' => true
		));
	}
	
	/**
	 * Returns spider information, if the given user agent identifies a spider.
	 * Otherwise returns false.
	 * 
	 * @param 	string		$userAgent
	 * @return	mixed
	 */
	protected static function isSpider($userAgent) {
		$spiderList = WCF::getCache()->get('spiders');
		$userAgent = strtolower($userAgent);
		
		foreach ($spiderList as $spider) {
			if (strpos($userAgent, $spider['spiderIdentifier']) !== false) {
				return $spider;
			}
		}
	
		return false;
	}
	
	/**
	 * @see SessionFactory::readSessionID()
	 */
	protected function readSessionID() {
		$sessionID = parent::readSessionID();
		
		// get sessionID from cookie
		if (empty($sessionID) && isset($_COOKIE[COOKIE_PREFIX.'cookieHash'])) {
			$sessionID = $_COOKIE[COOKIE_PREFIX . 'cookieHash'];
		}
		
		return $sessionID;
	}
}
?>