<?php
// imports
if (!defined('NO_IMPORTS')) {
	require_once(WCF_DIR.'lib/system/template/TemplatePluginCompiler.class.php');
	require_once(WCF_DIR.'lib/system/template/TemplateCompiler.class.php');
	require_once(WCF_DIR.'lib/system/exception/SystemException.class.php');
}

/**
 * The 'assign' compiler function calls the assign function on the template object.
 * 
 * Usage:
 * {assign var=name value="foo"}
 *
 * @package	com.woltlab.wcf.system.template.plugin
 * @author 	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class TemplatePluginCompilerAssign implements TemplatePluginCompiler {
	/**
	 * @see TemplatePluginCompiler::executeStart()
	 */
	public function executeStart($tagArgs, TemplateCompiler $compiler) {
		if (!isset($tagArgs['var'])) {
			throw new SystemException($compiler->formatSyntaxError("missign 'var' argument in assign tag", $compiler->getCurrentTemplate(), $compiler->getCurrentLineNo()), 12001);
		}
		if (!isset($tagArgs['value'])) {
			throw new SystemException($compiler->formatSyntaxError("missign 'value' argument in assign tag", $compiler->getCurrentTemplate(), $compiler->getCurrentLineNo()), 12001);
		}
				
		return "<?php \$this->assign(".$tagArgs['var'].", ".$tagArgs['value']."); ?>";
	}
	
	/**
	 * @see TemplatePluginCompiler::executeEnd()
	 */
	public function executeEnd(TemplateCompiler $compiler) {
		throw new SystemException($compiler->formatSyntaxError("unknown tag {/assign}", $compiler->getCurrentTemplate(), $compiler->getCurrentLineNo()), 12003);
	}
}
?>