<?php
// imports
if (!defined('NO_IMPORTS')) {
	require_once(WCF_DIR.'lib/system/template/TemplatePluginFunction.class.php');
	require_once(WCF_DIR.'lib/system/template/TemplateCompiler.class.php');
	require_once(WCF_DIR.'lib/system/exception/SystemException.class.php');
}

/**
 * The 'implode' compiler function joins array elements with a string.
 * 
 * Usage:
 * {implode from=$array key=bar item=foo glue=";"}{$foo}{/implode}
 *
 * @package	com.woltlab.wcf.system.template.plugin
 * @author 	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class TemplatePluginCompilerImplode implements TemplatePluginCompiler {
	protected $tagStack = array();
	
	/**
	 * @see TemplatePluginCompiler::executeStart()
	 */
	public function executeStart($tagArgs, TemplateCompiler $compiler) {
		$compiler->pushTag('implode');
		
		if (!isset($tagArgs['from'])) {
			throw new SystemException($compiler->formatSyntaxError("missign 'from' argument in implode tag", $compiler->getCurrentTemplate(), $compiler->getCurrentLineNo()), 12001);
		}
		if (!isset($tagArgs['item'])) {
			throw new SystemException($compiler->formatSyntaxError("missign 'item' argument in implode tag", $compiler->getCurrentTemplate(), $compiler->getCurrentLineNo()), 12001);
		}
		
		// dequote item
		$tagArgs['item'] = $compiler->dequote($tagArgs['item']);
		if (StringUtil::substring($tagArgs['item'], 0, 1) != '$') {
			$tagArgs['item'] = '$'.$tagArgs['item'];
			$tagArgs['item'] = $compiler->compileVariableTag($tagArgs['item']);
		}
		
		// dequote key
		if (isset($tagArgs['key'])) {
			$tagArgs['key'] = $compiler->dequote($tagArgs['key']);
			if (StringUtil::substring($tagArgs['key'], 0, 1) != '$') {
				$tagArgs['key'] = '$'.$tagArgs['key'];
				$tagArgs['key'] = $compiler->compileVariableTag($tagArgs['key']);
			}
		}
		
		$hash = StringUtil::getRandomID();
		$glue = isset($tagArgs['glue']) ? $compiler->dequote($tagArgs['glue']) : ', ';
		$this->tagStack[] = array('hash' => $hash, 'glue' => $glue);
		
		$phpCode = "<?php\n";
		$phpCode .= "\$_length".$hash." = count(".$tagArgs['from'].");\n";
		$phpCode .= "\$_i".$hash." = 0;\n";
		$phpCode .= "foreach (".$tagArgs['from']." as ".(isset($tagArgs['key']) ? $tagArgs['key']." => " : '').$tagArgs['item'].") { ?>";
		return $phpCode;
	}
	
	/**
	 * @see TemplatePluginCompiler::executeEnd()
	 */
	public function executeEnd(TemplateCompiler $compiler) {
		$compiler->popTag('implode');
		$tagArgs = array_pop($this->tagStack);
		
		$phpCode = "<?php\n";
		$phpCode .= "if (++\$_i".$tagArgs['hash']." < \$_length".$tagArgs['hash'].") { ?>".$tagArgs['glue']."<?php }\n";
		$phpCode .= "} ?>";
		
		return $phpCode;
	}
}
?>