<?php
// imports
if (!defined('NO_IMPORTS')) {
	require_once(WCF_DIR.'lib/system/template/TemplatePluginCompiler.class.php');
	require_once(WCF_DIR.'lib/system/template/TemplateCompiler.class.php');
}

/**
 * The 'lang' compiler function compiles dynamic language variables.
 * Warning: a dynamic language variable does not support template scripting currently.
 * 
 * Usage:
 * {lang}$blah{/lang}
 * {lang var=$x}foo{/lang}
 *
 * @package	com.woltlab.wcf.system.template.plugin
 * @author 	Marcel Werk
 * @copyright	2001-2007 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 */
class TemplatePluginCompilerLang implements TemplatePluginCompiler {
	/**
	 * @see TemplatePluginCompiler::executeStart()
	 */
	public function executeStart($tagArgs, TemplateCompiler $compiler) {
		$compiler->pushTag('lang');
		
		$newTagArgs = array();
		foreach ($tagArgs as $key => $arg) {
			$newTagArgs['$'.$key] = 'StringUtil::encodeHTML('.$arg.')';
		}
		
		$tagArgs = $compiler->makeArgString($newTagArgs);
		return "<?php \$this->tagStack[] = array('lang', array($tagArgs)); ob_start(); ?>";
	}
	
	/**
	 * @see TemplatePluginCompiler::executeEnd()
	 */
	public function executeEnd(TemplateCompiler $compiler) {
		$compiler->popTag('lang');
		$hash = StringUtil::getRandomID();
		return "<?php \$_lang".$hash." = ob_get_contents(); ob_end_clean(); echo WCF::getLanguage()->get(\$_lang".$hash.", \$this->tagStack[count(\$this->tagStack) - 1][1]); array_pop(\$this->tagStack); ?>";
	}
}
?>