/* +++ tables +++ */
DROP TABLE IF EXISTS wcf1_acp_menu_item;
CREATE TABLE wcf1_acp_menu_item (
	menuItemID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	menuItem varchar(255) NOT NULL default '',
	parentMenuItem varchar(255) NOT NULL default '',
	menuItemLink varchar(255) NOT NULL default '',
	menuItemIcon varchar(255) NOT NULL default '', 
	showOrder int(10) unsigned NOT NULL default 0,
	permissions text NULL,
	PRIMARY KEY (menuItemID),
	UNIQUE KEY (menuItem, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_acp_session;
CREATE TABLE wcf1_acp_session (
	sessionID char(40) NOT NULL default '',
	packageID int(10) unsigned NOT NULL default 0,
	userID int(10) unsigned NOT NULL default 0,
	ipAddress varchar(15) NOT NULL default '',
	userAgent varchar(255) NOT NULL default '',
	lastActivityTime int(10) unsigned NOT NULL default 0,
	requestURI varchar(255) NOT NULL default '',
	requestMethod varchar(4) NOT NULL default '',
	username varchar(255) NOT NULL default '',
	userData mediumtext NULL,
	sessionVariables mediumtext NULL,
	PRIMARY KEY (sessionID,packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_acp_template;
CREATE TABLE wcf1_acp_template (
	templateID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	templateName varchar(255) NOT NULL default '',
	PRIMARY KEY (templateID),
	UNIQUE KEY (packageID, templateName)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_acp_template_patch;
CREATE TABLE wcf1_acp_template_patch (
	patchID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	templateID int(10) unsigned NOT NULL default 0,
	success tinyint(1) unsigned NOT NULL default 0,
	fuzzFactor int(10) unsigned NOT NULL default 0,
	patch LONGTEXT,
	PRIMARY KEY  (patchID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_event_listener;
CREATE TABLE wcf1_event_listener (
	listenerID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default '0',
	environment enum('user','admin') NOT NULL default 'user',
	eventClassName varchar(80) NOT NULL default '',
	eventName varchar(50) NOT NULL default '',
	listenerClassFile varchar(200) NOT NULL default '',
	inherit tinyint(1) unsigned NOT NULL default 0,
	PRIMARY KEY  (listenerID),
	UNIQUE KEY packageID (packageID,environment,eventClassName,eventName,listenerClassFile)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_group;
CREATE TABLE wcf1_group (
	groupID int(10) unsigned NOT NULL auto_increment,
	groupName varchar(255) NOT NULL default '',
	groupType tinyint(1) unsigned NOT NULL default 0, 
	PRIMARY KEY (groupID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_group_option_category;
CREATE TABLE wcf1_group_option_category (
	categoryID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	categoryName varchar(255) NOT NULL default '',
	parentCategoryName varchar(255) NOT NULL default '',
	showOrder int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (categoryID),
	UNIQUE KEY (categoryName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_group_option;
CREATE TABLE wcf1_group_option  (
	optionID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	optionName varchar(255) NOT NULL default '',
	categoryName varchar(255) NOT NULL default '',
	optionType varchar(255) NOT NULL default '',
	defaultValue mediumtext NULL,
	validationPattern text NULL,
	enableOptions mediumtext NULL,
	showOrder int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (optionID),
	UNIQUE KEY (optionName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_group_option_value;
CREATE TABLE wcf1_group_option_value  (
	groupID int(10) unsigned NOT NULL default 0,
	optionID int(10) unsigned NOT NULL default 0,
	optionValue mediumtext NOT NULL,
	PRIMARY KEY (groupID, optionID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_language;
CREATE TABLE wcf1_language (
	languageID int(10) unsigned NOT NULL auto_increment,
	languageCode varchar(20) NOT NULL default '',
	languageEncoding varchar(20) NOT NULL default '',
	isDefault tinyint(1) unsigned NOT NULL default 0,
	hasContent tinyint(1) unsigned NOT NULL default 0,
	PRIMARY KEY (languageID),
	UNIQUE KEY (languageCode)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_language_to_packages;
CREATE TABLE wcf1_language_to_packages (
	languageID int(10) unsigned NOT NULL default 0,
	packageID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (languageID,packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_language_category;
CREATE TABLE wcf1_language_category (
	languageCategoryID int(10) unsigned NOT NULL auto_increment,
	languageCategory varchar(255) NOT NULL default '',
	PRIMARY KEY (languageCategoryID),
	UNIQUE KEY (languageCategory)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_language_item;
CREATE TABLE wcf1_language_item (
	languageItemID int(10) unsigned NOT NULL auto_increment,
	languageID int(10) unsigned NOT NULL default 0,
	languageItem varchar(255) NOT NULL default '',
	languageItemValue mediumtext NOT NULL,
	languageCategoryID int(10) unsigned NOT NULL default 0,
	packageID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (languageItemID),
	UNIQUE KEY (languageItem, packageID, languageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_option_category;
CREATE TABLE wcf1_option_category (
	categoryID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	categoryName varchar(255) NOT NULL default '',
	parentCategoryName  varchar(255) NOT NULL default '',
	showOrder int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (categoryID),
	UNIQUE KEY (categoryName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_option;
CREATE TABLE wcf1_option (
	optionID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	optionName varchar(255) NOT NULL default '',
	categoryName varchar(255) NOT NULL default '',
	optionType varchar(255) NOT NULL default '',
	optionValue mediumtext NULL,
	validationPattern text NULL,
	selectOptions mediumtext NULL,
	enableOptions mediumtext NULL,
	showOrder int(10) unsigned NOT NULL default 0,
	hidden tinyint(1) unsigned NOT NULL default 0,
	PRIMARY KEY (optionID),
	UNIQUE KEY (optionName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_dependency;
CREATE TABLE wcf1_package_dependency (
	packageID int(10) unsigned NOT NULL default 0,
	dependency int(10) unsigned NOT NULL default 0,
	priority int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (packageID, dependency),
	KEY (dependency)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package;
CREATE TABLE wcf1_package (
	packageID int(10) unsigned NOT NULL auto_increment,
	package varchar(255) NOT NULL default '',
	packageDir varchar(255) NOT NULL default '',
	packageName varchar(255) NOT NULL default '',
	instanceNo int(10) unsigned NOT NULL default 1,
	packageDescription varchar(255) NOT NULL default '',
	packageVersion varchar(255) NOT NULL default '',
	packageDate int(10) unsigned NOT NULL default 0,
	packageURL varchar(255) NOT NULL default '',
	parentPackageID int(10) unsigned NOT NULL default 0,
	isUnique tinyint(1) unsigned NOT NULL default 0,
	standalone tinyint(1) unsigned NOT NULL default 0,
	author varchar(255) NOT NULL default '',
	authorURL varchar(255) NOT NULL default '',
	PRIMARY KEY (packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_installation_queue;
CREATE TABLE wcf1_package_installation_queue (
	queueID int(10) unsigned NOT NULL auto_increment,
	parentQueueID int(10) unsigned NOT NULL default 0,
	processNo int(10) unsigned NOT NULL default 0,
	userID int(10) unsigned NOT NULL default 0,
	package varchar(255) NOT NULL default '',
	packageID int(10) unsigned NOT NULL default 0,
	archive varchar(255) NOT NULL default '',
	action ENUM('install', 'update', 'uninstall', 'rollback') NOT NULL default 'install',
	cancelable tinyint(1) unsigned NOT NULL default 1,
	done tinyint(1) unsigned NOT NULL default 0,
	confirmInstallation tinyint(1) unsigned NOT NULL default 0,
	packageType ENUM('default', 'requirement', 'optional') NOT NULL default 'default',
	installationType ENUM('install', 'setup', 'other') NOT NULL default 'other',
	PRIMARY KEY (queueID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_installation_file_log;
CREATE TABLE wcf1_package_installation_file_log (
	packageID int(10) unsigned NOT NULL default 0,
	filename varchar(255) NOT NULL default '',
	PRIMARY KEY (packageID, filename)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_installation_plugin;
CREATE TABLE wcf1_package_installation_plugin (
	pluginName varchar(255) NOT NULL default '',
	packageID int(10) unsigned NOT NULL default 0,
	priority tinyint(1) unsigned NOT NULL default 0, 
	PRIMARY KEY (pluginName)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_installation_sql_log;
CREATE TABLE wcf1_package_installation_sql_log ( 
	packageID int(10) unsigned NOT NULL default 0, 
	sqlTable varchar(100) NOT NULL default '', 
	sqlColumn varchar(100) NOT NULL default '', 
	sqlIndex varchar(100) NOT NULL default '', 
	PRIMARY KEY (packageID, sqlTable, sqlColumn, sqlIndex) 
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_requirement;
CREATE TABLE wcf1_package_requirement (
	packageID int(10) unsigned NOT NULL default 0,
	requirement int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (packageID, requirement)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_requirement_map;
CREATE TABLE wcf1_package_requirement_map (
	packageID int(10) unsigned NOT NULL default 0,
	requirement int(10) unsigned NOT NULL default 0,
	level int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (packageID, requirement),
	KEY (requirement)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_update_server;
CREATE TABLE wcf1_package_update_server (
	packageUpdateServerID int(10) unsigned NOT NULL auto_increment,
	server varchar(255) NOT NULL default '',
	status varchar(10) NOT NULL default '',
	statusUpdate tinyint(1) unsigned NOT NULL default 1,
	errorText text NULL,
	updatesFile tinyint(1) unsigned NOT NULL default 0,
	timestamp int(10) unsigned NOT NULL default 0,
	htUsername varchar(50) NOT NULL default '',
	htPassword varchar(40) NOT NULL default '',
	PRIMARY KEY  (packageUpdateServerId)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_update;
CREATE TABLE wcf1_package_update (
	packageUpdateID int(10) unsigned NOT NULL auto_increment,
	packageUpdateServerID int(10) unsigned NOT NULL default 0,
	package varchar(255) NOT NULL default '',
	packageName varchar(255) NOT NULL default '',
	packageDescription varchar(255) NOT NULL default '',
	author varchar(255) NOT NULL default '',
	authorURL varchar(255) NOT NULL default '',
	standalone tinyint(1) NOT NULL DEFAULT 0,
	plugin varchar(255) NOT NULL default '',
	PRIMARY KEY (packageUpdateID),
	UNIQUE KEY (packageUpdateServerID, package)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_update_version;
CREATE TABLE wcf1_package_update_version (
	packageUpdateVersionID int(10) unsigned NOT NULL auto_increment,
	packageUpdateID int(10) unsigned NOT NULL default 0,
	packageVersion varchar(50) NOT NULL default '',
	updateType varchar(10) NOT NULL default '',
	timestamp int(10) unsigned NOT NULL default 0,
	file varchar(255) NOT NULL default '',
	PRIMARY KEY  (packageUpdateVersionID),
	UNIQUE KEY (packageUpdateID, packageVersion)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_update_requirement;
CREATE TABLE wcf1_package_update_requirement (
	packageUpdateVersionID int(10) unsigned NOT NULL default 0,
	package varchar(255) NOT NULL default '',
	minversion varchar(50) NOT NULL default '',
	UNIQUE KEY (packageUpdateVersionID, package)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_package_update_fromversion;
CREATE TABLE wcf1_package_update_fromversion (
	packageUpdateVersionID int(10) unsigned NOT NULL default 0,
	fromversion varchar(50) NOT NULL default '',
	UNIQUE KEY (packageUpdateVersionID, fromversion)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_search;
CREATE TABLE wcf1_search (
	searchID int(10) unsigned NOT NULL auto_increment,
	userID int(10) unsigned NOT NULL default 0,
	searchData mediumtext NOT NULL,
	searchDate int(10) unsigned NOT NULL default 0,
	searchType varchar(255) NOT NULL default '',
	searchHash char(40) NOT NULL default '',
	PRIMARY KEY (searchID),
	KEY (searchHash)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_session;
CREATE TABLE wcf1_session (
	sessionID char(40) NOT NULL default '',
	packageID int(10) unsigned NOT NULL default 0,
	userID int(10) unsigned NOT NULL default 0,
	ipAddress varchar(15) NOT NULL default '',
	userAgent varchar(255) NOT NULL default '',
	lastActivityTime int(10) unsigned NOT NULL default 0,
	requestURI varchar(255) NOT NULL default '',
	requestMethod varchar(4) NOT NULL default '',
	userData mediumtext NULL,
	sessionVariables mediumtext NULL,
	username varchar(255) NOT NULL default '',
	spiderID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (sessionID),
	KEY (packageID, lastActivityTime, spiderID),
	KEY (userID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_spider;
CREATE TABLE wcf1_spider (
	spiderID int(10) unsigned NOT NULL auto_increment,
	spiderIdentifier varchar(255) default '',
	spiderName varchar(255) default '',
	spiderURL varchar(255) default '',
	PRIMARY KEY (spiderID),
	UNIQUE KEY (spiderIdentifier)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_template;
CREATE TABLE wcf1_template (
	templateID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	templateName varchar(255) NOT NULL default '',
	PRIMARY KEY (templateID),
	KEY (packageID, templateName)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_template_patch;
CREATE TABLE wcf1_template_patch (
	patchID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	templateID int(10) unsigned NOT NULL default 0,
	success tinyint(1) unsigned NOT NULL default 0,
	fuzzFactor int(10) unsigned NOT NULL default 0,
	patch LONGTEXT,
	PRIMARY KEY  (patchID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user;
CREATE TABLE wcf1_user (
	userID int(10) unsigned NOT NULL auto_increment,
	username varchar(255) NOT NULL default '',
	email varchar(255) NOT NULL default '',
	password varchar(40) NOT NULL default '',
	salt varchar(40) NOT NULL default '',
	languageID int(10) unsigned NOT NULL default 0,
	registrationDate int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (userID),
	KEY (username)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user_to_groups;
CREATE TABLE wcf1_user_to_groups (
	userID int(10) unsigned NOT NULL default 0,
	groupID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (userID,groupID),
	KEY (groupID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user_to_languages;
CREATE TABLE wcf1_user_to_languages (
	userID int(10) unsigned NOT NULL default 0,
	languageID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (userID,languageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user_option_category;
CREATE TABLE wcf1_user_option_category (
	categoryID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	categoryName varchar(255) NOT NULL default '',
	categoryIconS varchar(255) NOT NULL default '',
	categoryIconM varchar(255) NOT NULL default '',
	parentCategoryName varchar(255) NOT NULL default '',
	showOrder int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (categoryID),
	UNIQUE KEY (categoryName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user_option;
CREATE TABLE wcf1_user_option (
	optionID int(10) unsigned NOT NULL auto_increment,
	packageID int(10) unsigned NOT NULL default 0,
	optionName varchar(255) NOT NULL default '',
	categoryName varchar(255) NOT NULL default '',
	optionType varchar(255) NOT NULL default '',
	defaultValue mediumtext NULL,
	validationPattern text NULL,
	selectOptions mediumtext NULL,
	enableOptions mediumtext NULL,
	required tinyint(1) unsigned NOT NULL default 0,
	editable tinyint(1) unsigned NOT NULL default 0, 
	visible tinyint(1) unsigned NOT NULL default 0, 
	outputClass varchar(255) NOT NULL default '',
	searchable tinyint(1) unsigned NOT NULL default 0,
	showOrder int(10) unsigned NOT NULL default 0,
	disabled tinyint(1) unsigned NOT NULL default 0,
	PRIMARY KEY (optionID),
	UNIQUE KEY (optionName, packageID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS wcf1_user_option_value;
CREATE TABLE wcf1_user_option_value (
	userID int(10) unsigned NOT NULL default 0,
	PRIMARY KEY (userID)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

/* +++ default inserts +++ */
-- default user groups
INSERT INTO	wcf1_group
		(groupID, groupName, groupType)
VALUES	(1, 'Everyone', 1),
		(2, 'Guests', 2),
		(3, 'Users', 3),
		(4, 'Administrators', 4),
		(5, 'Moderators', 4),
		(6, 'Super Moderators', 4);
		
-- default user group options
INSERT INTO	wcf1_group_option
		(optionID, optionName, categoryName, optionType, defaultValue, showOrder)
VALUES		(1, 'admin.general.canUseAcp', 'admin.general', 'boolean', '0', 1),
		(2, 'admin.system.package.canInstallPackage', 'admin.system.package', 'boolean', '0', 1);
		
-- default user group option values
INSERT INTO	wcf1_group_option_value
		(groupID, optionID, optionValue)
VALUES	(1, 1, '0'), (1, 2, '0'), -- Everyone
		(2, 1, '0'), (2, 2, '0'), -- Guests
		(3, 1, '0'), (3, 2, '0'), -- Users
		(4, 1, '1'), (4, 2, '1'), -- Administrators
		(5, 1, '0'), (5, 2, '0'), -- Moderators
		(6, 1, '0'), (6, 2, '0'); -- Super Moderators
		
-- default update servers
INSERT INTO 	wcf1_package_update_server
		(packageUpdateServerID, server, status, statusUpdate, errorText, updatesFile, timestamp, htUsername, htPassword)
VALUES 		(1, 'http://update.woltlab.com', 'online', 1, NULL, 0, 1168257450, '', '');
INSERT INTO 	wcf1_package_update_server
		(packageUpdateServerID, server, status, statusUpdate, errorText, updatesFile, timestamp, htUsername, htPassword)
VALUES 		(2, 'http://community.woltlab.com/packages/', 'online', 1, NULL, 0, 1168257450, '', '');

-- search engine spiders
INSERT INTO wcf1_spider (spiderID, spiderIdentifier, spiderName, spiderURL) VALUES
(1, 'ABCdatos', 'ABCdatos BotLink', 'http://www.robotstxt.org/wc/active/html/abcdatos.html'),
(2, 'abot/', 'abot', 'http://www.abot.com/'),
(3, 'Accelatech RSSCrawler', 'Accelatech', ''),
(4, 'Accoona-AI-Agent', 'Accoona', 'http://accoona.com/about/about_accoona.jsp'),
(5, 'aconon Index', 'aconon Index  (raubfische.de)', ''),
(6, 'Ahoy!', 'Ahoy!', 'http://www.robotstxt.org/wc/active/html/ahoythehomepagefinder.html'),
(7, 'ia_archiver', 'Alexa', ''),
(8, 'AlkalineBOT', 'Alkaline', 'http://www.robotstxt.org/wc/active/html/Alkaline.html'),
(9, 'http://www.almaden.ibm.com/cs/crawler', 'Almaden Crawler', 'http://www.almaden.ibm.com/cs/crawler/'),
(10, 'EMC Spider', 'ananzi', ''),
(11, 'Anthill', 'Anthill', 'http://www.robotstxt.org/wc/active/html/anthill.html'),
(12, 'Aport', 'Aport', 'http://www.aport.ru/'),
(13, 'AppleSyndication', 'Apple', ''),
(14, 'Arachnophilia', 'Arachnophilia', 'http://www.robotstxt.org/wc/active/html/arachnophilia.html'),
(15, 'Araneo', 'Araneo', 'http://www.robotstxt.org/wc/active/html/araneo.html'),
(16, 'ArchitextSpider', 'ArchitextSpider', 'http://www.robotstxt.org/wc/active/html/architext.html'),
(17, 'arks/1.0', 'arks', 'http://www.robotstxt.org/wc/active/html/arks.html'),
(18, 'ASpider', 'ASpider', 'http://www.robotstxt.org/wc/active/html/aspider.html'),
(19, 'ATN_Worldwide', 'ATN Worldwide', 'http://www.robotstxt.org/wc/active/html/atn.txt.html'),
(20, 'Atomz', 'Atomz.com', 'http://www.robotstxt.org/wc/active/html/atomz.html'),
(21, 'AURESYS', 'AURESYS', 'http://www.robotstxt.org/wc/active/html/auresys.html'),
(22, 'BackRub', 'BackRub', 'http://www.robotstxt.org/wc/active/html/backrub.html'),
(23, 'Baiduspider', 'Baiduspider', 'http://www.baidu.com/search/spider.htm'),
(24, 'bbot', 'BBot', 'http://www.robotstxt.org/wc/active/html/bbot.html'),
(25, 'BecomeBot', 'BecomeBot', 'http://www.become.com/webmasters.html'),
(26, 'Big Brother', 'Big Brother', 'http://www.robotstxt.org/wc/active/html/bigbrother.html'),
(27, 'BigmirSpider', 'Bigmir', 'http://www.bigmir.net/'),
(28, 'Bitacle bot', 'Bitacle', 'http://bitacle.org/'),
(29, 'Biz360 Spider', 'Biz', 'http://www.biz360.com'),
(30, 'Bjaaland', 'Bjaaland', 'http://www.robotstxt.org/wc/active/html/bjaaland.html'),
(31, 'BlackWidow', 'BlackWidow', 'http://www.robotstxt.org/wc/active/html/blackwidow.html'),
(32, 'BlogCrawler by Xango', 'BlogCrawler', ''),
(33, 'blogdb', 'BlogDb', 'http://blogdb.jp'),
(34, 'blog search engine by BlogFan.ORG', 'BlogFan', 'http://www.blogfan.org'),
(35, 'Bloglines', 'Bloglies', 'http://www.bloglines.com'),
(36, 'BlogPulse (ISSpider-3.0)', 'BlogPulse', ''),
(37, 'BlogSearch', 'BlogSearch', 'http://www.icerocket.com'),
(38, 'BlogsNowBot', 'BlogsNow', 'http://www.blogsnow.com/'),
(39, 'BlogStreetBot', 'BlogStreetBot', 'http://www.blogstreet.com/'),
(40, 'Bulkfeeds', 'BlogStreetBot', 'http://bulkfeeds.net'),
(41, 'BoardPulse', 'BoardPulse', 'http://www.boardpulse.com/'),
(42, 'BoardReader', 'BoardReader', 'http://www.boardreader.com/aboutus.asp'),
(43, 'BoardViewer', 'BoardViewer', 'http://www.boardviewer.com/'),
(44, 'boitho.com-robot', 'Boitho', 'http://www.boitho.com/bot.html'),
(45, 'borg-bot', 'Borg-Bot', 'http://www.robotstxt.org/wc/active/html/borg-bot.html'),
(46, 'BSpider', 'BSpider', 'http://www.robotstxt.org/wc/active/html/bspider.html'),
(47, 'CACTVS Chemistry Spider', 'CACTVS Chemistry', ''),
(48, 'Calif', 'Calif', ''),
(49, 'CaRP/3.6Evolution', 'CaRP', 'http://www.biz360.com'),
(50, 'Checkbot', 'Checkbot', ''),
(51, 'ChristCrawler.com', 'ChristCrawler.com', ''),
(52, 'www.cienciaficcion.net', 'cIeNcIaFiCcIoN.nEt', ''),
(53, 'CipinetBot', 'Cipinet', 'http://www.cipinet.com/bot.html'),
(54, 'CJNetworkQuality', 'CJNetworkQuality', 'http://www.cj.com/networkquality/'),
(55, 'CMC/0.01', 'CMC/0.01', ''),
(56, 'ColdFusion', 'ColdFusion', ''),
(57, 'combine', 'Combine System', ''),
(58, 'Crawler (cometsearch@cometsystems.com)', 'cometsystems.com', ''),
(59, 'ComputingSite Robi/1.0', 'ComputingSite Robi/1.0', ''),
(60, 'conceptbot', 'Conceptbot', ''),
(61, 'Cooby.de Crawler', 'Cooby.de Crawler', ''),
(62, 'CoolBot', 'CoolBot', ''),
(63, 'Cusco', 'Cusco', ''),
(64, 'CyberSpyder', 'CyberSpyder', ''),
(65, 'daypopbot', 'daypop', ''),
(66, 'DeadLinkCheck', 'DeadLinkCheck', 'http://dlc.sourceforge.net/'),
(67, 'DesertRealm.com', 'Desert Realm', ''),
(68, 'Deweb', 'DeWeb(c)', ''),
(69, 'Die Blinde Kuh', 'Die Blinde Kuh', 'http://www.robotstxt.org/wc/active/html/blindekuh.html'),
(70, 'dienstspider', 'DienstSpider', ''),
(71, 'Digger/1.0 JDK/1.3.0', 'Digger', ''),
(72, 'Digimarc WebReader', 'Digimarc MarcSpider', ''),
(73, 'Digimarc CGIReader', 'Digimarc Marcspider/CGI', ''),
(74, 'DIIbot', 'Digital Integrity Robot', ''),
(75, 'grabber', 'Direct Hit Grabber', ''),
(76, 'DNAbot/1.0', 'DNAbot', ''),
(77, 'DotTK SiteCheck', 'Dot.tk', 'http://www.dot.tk'),
(78, 'DragonBot/1.0 libwww/5.0', 'DragonBot', ''),
(79, 'DWCP/2.0', 'DWCP (Dridus'' Web Cataloging Project)', ''),
(80, 'e-SocietyRobot', 'e-Society', 'http://www.yama.info.waseda.ac.jp/~yamana/es/index_eng.htm'),
(81, 'exactseek-pagereaper', 'eaxactseek-page', ''),
(82, 'EbiNess/0.01a', 'EbiNess', ''),
(83, 'edgeio-retriever', 'Edgeio', 'http://www.edgeio.com'),
(84, 'EIT-Link-Verifier-Robot/0.2', 'EIT Link Verifier Robot', ''),
(85, 'elfinbot', 'ELFINBOT', ''),
(86, 'Emacs-w3/v[0-9\\.]+', 'Emacs-w3 Search Engine', ''),
(87, 'esther', 'Esther', ''),
(88, 'EuripBot/', 'EuripBot', ''),
(89, 'Evliya Celebi', 'Evliya Celebi', ''),
(90, 'ExactSeek_Spider', 'ExactSeek_Spider', 'http://www.askjeevs.com'),
(91, 'NG/2.0', 'ExaLead', 'http://botspotter.net/bs-389.html'),
(92, 'ExaBot', 'ExaLead Beta', 'http://beta.exalead.com/search/C=0/2p=Help.7'),
(93, 'fast-webcrawler', 'FAST / AlltheWeb', 'http://help.yahoo.com/help/us/ysearch/slurp/index.html'),
(94, 'FastCrawler', 'FastCrawler', ''),
(95, 'Feed24.com', 'Feed24', 'http://www.feed24.com'),
(96, 'FeedBlitz', 'FeedBlitz', 'http://www.feedblitz.com'),
(97, 'FeedBurner', 'FeedBurner', 'http://www.FeedBurner.com'),
(98, 'FeedFetcher-Google', 'FeedFetcher-Google', 'http://www.google.com/feedfetcher.html'),
(99, 'UniversalFeedParser', 'FeedParser', 'http://www.feedparser.org'),
(100, 'Feedster Crawler', 'Feedster', 'http://www.feedstermedia.com/'),
(101, 'FeedValidator/', 'FeedValidator', ''),
(102, 'FEHLSTART Superspider', 'FEHLSTART', ''),
(103, 'FelixIDE', 'Felix IDE', ''),
(104, 'ESIRover', 'FetchRover', ''),
(105, 'fido', 'fido', ''),
(106, 'findlinks', 'FindLinks', 'http://wortschatz.uni-leipzig.de/findlinks/'),
(107, 'FindoryBot', 'Findroy', 'http://www.findory.com'),
(108, 'Fish-Search-Robot', 'Fish search', ''),
(109, 'Mozilla/4.0 (compatible: FDSE robot)', 'Fluid Dynamics', ''),
(110, 'fouineur.9bit.qc.ca', 'Fouineur', ''),
(111, 'Freecrawl', 'Freecrawl', ''),
(112, 'FunnelWeb', 'FunnelWeb', ''),
(113, 'GaisBot', 'Gais', 'http://gais.cs.ccu.edu.tw/robot.php'),
(114, 'gamekitbot', 'GAMEKIT', 'http://www.uchoose.de/crawler/gamekitbot/'),
(115, 'gammaSpider', 'gammaSpider', ''),
(116, 'gazz', 'gazz', ''),
(117, 'gcreep', 'GCreep', ''),
(118, 'genieBot', 'genieBot', 'http://64.5.245.11/faq/faq.html'),
(119, 'geourl', 'GeoURL', 'http://geourl.org/bot.html'),
(120, 'GetterroboPlus', 'GetterroboPlus Puu', ''),
(121, 'GetURL.rexx', 'GetURL', ''),
(122, 'Gigabot', 'Gigabot', 'http://www.gigablast.com/spider.html'),
(123, 'Girafabot', 'Girafabot', 'http://www.girafa.com/'),
(124, 'Goku', 'Goku', 'http://goku.ru/bot.htm; bot@goku.ru'),
(125, 'Golem', 'Golem', ''),
(126, 'gonzo', 'Gonzo', ''),
(127, 'Googlebot/', 'Google', 'http://www.google.com/bot.html'),
(128, 'Mediapartners-Google', 'Google AdSense', 'https://www.google.com/adsense/faq'),
(129, 'Googlebot-Image', 'Googlebot-Image', 'http://www.googlebot.com/bot.html'),
(130, 'Gpostbot', 'Gpostbot', 'http://www.gpost.info/help.php?c=bot'),
(131, 'griffon', 'Griffon', ''),
(132, 'Gromit', 'Gromit', ''),
(133, 'http://grub.org', 'Grub Client', ''),
(134, 'Gulper Web Bot', 'Gulper Bot', ''),
(135, 'H?m?h?kki', 'H?m?h?kki', 'http://www.robotstxt.org/wc/active/html/finnish.html'),
(136, 'havIndex', 'havIndex', ''),
(137, 'HeinrichderMiragoRobot', 'HeinrichderMiragoRobot', ''),
(138, 'HenryTheMiragoRobot', 'HenryTheMiragoRobot', ''),
(139, 'heritrix', 'Heritrix', 'http://www.worio.com'),
(140, 'HKU WWW Robot', 'HKU WWW Octopus', ''),
(141, 'HolyCowDude', 'HolyCowDude', 'http://www.holycowdude.com/spider.htm'),
(142, 'Hometown', 'Hometown', ''),
(143, 'htdig', 'ht://Dig', ''),
(144, 'AITCSRobot', 'HTML Index', ''),
(145, 'HTMLgobble', 'HTMLgobble', ''),
(146, 'I Robot', 'I, Robot', ''),
(147, 'iajaBot', 'iajaBot', ''),
(148, 'IBM_Planetwide', 'IBM_Planetwide', ''),
(149, '+http://www.icerocket.com/', 'IceRocket', 'http://www.icerocket.com/'),
(150, 'ichiro', 'ichiro', ''),
(151, 'IlTrovatore-Setaccio', 'IlTrovatore-Setaccio', 'http://www.iltrovatore.it/aiuto/faq.html'),
(152, 'image.kapsi.net', 'image.kapsi.net', ''),
(153, 'Mozilla 3.01 PBWF (Win95)', 'Imagelock', ''),
(154, 'IncyWincy', 'IncyWincy', ''),
(155, 'Informant', 'Informant', ''),
(156, 'InfoSeek Robot', 'InfoSeek Robot 1.0', ''),
(157, 'Infoseek Sidewinder', 'Infoseek Sidewinder', ''),
(158, 'InfoSpiders', 'InfoSpiders', ''),
(159, 'INGRID', 'Ingrid', ''),
(160, 'slurp@inktomi', 'Inktomi', ''),
(161, 'Insitor', 'Insitor', 'http://www.insitor.de/'),
(162, 'inspectorwww', 'Inspector Web', ''),
(163, 'IAGENT', 'IntelliAgent', ''),
(164, 'Intelliseek', 'Intelliseek', 'http://www.intelliseek.com/'),
(165, 'Internet Cruiser Robot', 'Internet Cruiser', ''),
(166, 'internetseer', 'Internet Seer', ''),
(167, 'sharp-info-agent', 'Internet Shinchakubin', ''),
(168, 'InternetLinkAgent', 'InternetLinkAgent', ''),
(169, 'Iron33', 'Iron33', ''),
(170, 'IsraeliSearch', 'Israeli-search', ''),
(171, 'itchBot', 'itch', 'http://www.itch.com/infoforwebmasters.html'),
(172, 'JavaBee', 'JavaBee', ''),
(173, 'JBot', 'JBot', ''),
(174, 'JCrawler', 'JCrawler', ''),
(175, 'JetBot', 'JetEye', 'http://www.jeteye.com/jetbot.html'),
(176, 'JoBo', 'JoBo', ''),
(177, 'Jobot', 'Jobot', ''),
(178, 'JoeBot', 'JoeBot', ''),
(179, 'jumpstation', 'JumpStation', ''),
(180, 'Katipo', 'Katipo', ''),
(181, 'KDD-Explorer', 'KDD-Explorer', ''),
(182, 'KIT-Fireball', 'KIT-Fireball', ''),
(183, 'KO_Yappo_Robot', 'KO_Yappo_Robot', ''),
(184, 'LabelGrab', 'LabelGrabber', ''),
(185, 'larbin', 'larbin', ''),
(186, 'legs', 'legs', ''),
(187, 'linkalarm', 'Link Alarm', ''),
(188, 'Linkidator', 'Link Validator', ''),
(189, 'LinkScan Server', 'LinkScan', ''),
(190, 'LinkWalker', 'LinkWalker', ''),
(191, 'livedoorCheckers/', 'livedoorCheckers', ''),
(192, 'Lockon', 'Lockon', ''),
(193, 'logo.gif crawler', 'logo.gif', ''),
(194, 'Lycos', 'Lycos', ''),
(195, 'Magpie', 'Magpie', ''),
(196, 'MJ12bot', 'Majestics MJ12bot', ''),
(197, 'Mammoth', 'Mammoth', 'http://www.sli-systems.com'),
(198, 'Marvin', 'Marvin', ''),
(199, 'marvin/infoseek', 'marvin/infoseek', ''),
(200, 'M/3.8', 'Mattie', ''),
(201, 'MediaFox', 'MediaFox', ''),
(202, 'mercator', 'Mercator', 'http://research.compaq.com/SRC/mercator/'),
(203, 'MerzScope', 'MerzScope', ''),
(204, 'METASpider', 'META', 'http://www.meta.com.ua/'),
(205, 'MetaGer-LinkChecker', 'MetaGer', ''),
(206, 'MindCrawler', 'MindCrawler', ''),
(207, 'Miva', 'Miva', ''),
(208, 'UdmSearch', 'mnoGoSearch', ''),
(209, 'moget', 'moget', ''),
(210, 'MOMspider', 'MOMspider', ''),
(211, 'Monster', 'Monster', ''),
(212, 'Moreoverbot', 'Moreover', 'http://www.moreover.com'),
(213, 'Motor', 'Motor', ''),
(214, 'msnbot', 'MSNBot', ''),
(215, 'MuscatFerret', 'Muscat Ferret', ''),
(216, 'MwdSearch', 'Mwd.Search', ''),
(217, 'NPBot', 'NameProtect', ''),
(218, 'NaverBot', 'NaverBot', 'http://www.spidermatic.com/en/robot-spider/20'),
(219, 'NEC-MeshExplorer', 'NEC-MeshExplorer', ''),
(220, 'Nederland.zoek', 'Nederland.zoek', ''),
(221, 'NetCarta CyberPilot Pro', 'NetCarta WebMap', ''),
(222, 'Netcraft', 'Netcraft Web Server Survey', 'http://news.netcraft.com/'),
(223, 'NetMechanic', 'NetMechanic', ''),
(224, 'NetScoop', 'NetScoop', ''),
(225, 'newscan-online', 'newscan-online', ''),
(226, 'NextGenSearchBot 1', 'NextGenSearchBot', 'http://www.zoominfo.com/NextGenSearchBot'),
(227, 'NHSEWalker', 'NHSE Web Forager', ''),
(228, 'NIF', 'NIF', 'http://www.newsisfree.com/robot.php users'),
(229, 'NimbleCrawler', 'NimbleCrawler', 'http://www.healthline.com/aboutus.jsp'),
(230, 'Nomad', 'Nomad', ''),
(231, 'Norbert the Spider', 'Norbert', 'http://www.Burf.com'),
(232, 'Gulliver', 'Northern Light', ''),
(233, 'explorersearch', 'nzexplorer', ''),
(234, 'Occam', 'Occam', ''),
(235, 'Ocelli', 'Ocelli', 'http://www.globalspec.com/Ocelli'),
(236, 'Online24-Bot', 'Online24-Bot', ''),
(237, 'Openbot', 'Openbot', 'http://www.openfind.com.tw/robot.html'),
(238, 'Openfind', 'Openfind data gatherer', ''),
(239, 'Orbsearch', 'Orb Search', ''),
(240, 'PackRat', 'Pack Rat', ''),
(241, 'PageBoy', 'PageBoy', ''),
(242, 'ParaSite', 'ParaSite', ''),
(243, 'Patric', 'Patric', ''),
(244, 'PEGASUS', 'pegasus', ''),
(245, 'PerlCrawler/1.0 Xavatoria/2.0', 'PerlCrawler 1.0', ''),
(246, 'PGP-KA', 'PGP Key Agent', ''),
(247, 'Duppies', 'Phantom', ''),
(248, 'phpdig', 'PhpDig', ''),
(249, 'PiltdownMan', 'PiltdownMan', ''),
(250, 'Pimptrain''s robot', 'Pimptrain.com''s', ''),
(251, 'pingalink', 'PingALink', ''),
(252, 'Pioneer', 'Pioneer', ''),
(253, 'PluckFeedCrawler', 'Pluck', 'http://www.pluck.com'),
(254, 'PlumtreeWebAccessor', 'PlumtreeWebAccessor', ''),
(255, 'PodNova', 'PodNova', 'http://www.podnova.com'),
(256, 'Pompos', 'Pompos', 'http://dir.com/pompos.html'),
(257, 'Poppi', 'Poppi', ''),
(258, 'gestaltIconoclast', 'Popular Iconoclast', ''),
(259, 'PortalJuice.com', 'Portal Juice', ''),
(260, 'PortalBSpider', 'PortalB Spider', ''),
(261, 'www.kolinka.com', 'Project Kolinka Forum Search', 'http://www.kolinka.com/'),
(262, 'psbot', 'psbot', ''),
(263, 'Qango.com Web Directory', 'Qango', 'http://www.qango.com'),
(264, 'StackRambler', 'Rambler', 'http://www.rambler.ru/'),
(265, 'Raven', 'Raven Search', ''),
(266, 'Resume Robot', 'Resume Robot', ''),
(267, 'Road Runner: ImageScape Robot', 'Road Runner: The ImageScape Robot', ''),
(268, 'RHCS', 'RoadHouse Crawling System', ''),
(269, 'Robbie', 'Robbie the Robot', ''),
(270, 'RoboCrawl', 'RoboCrawl', ''),
(271, 'Robofox', 'RoboFox', ''),
(272, 'Robot du CRIM 1.0a', 'Robot Francoroute', ''),
(273, 'Robozilla', 'Robozilla', ''),
(274, 'Roverbot', 'Roverbot', ''),
(275, 'RSS-SPIDER', 'RSS Feed Seeker', 'http://www.rss-spider.com/fsb.php'),
(276, 'RuLeS', 'RuLeS', ''),
(277, 'SafetyNet Robot', 'SafetyNet', ''),
(278, 'SBIder', 'SBIder.', 'http://www.sitesell.com/sbider.html'),
(279, 'Scharia', 'Scharia', ''),
(280, 'Science-Index', 'Science-Index', ''),
(281, 'Scooter', 'Scooter', ''),
(282, 'SearchNZ', 'SearchNZ', 'http://www.searchnz.co.nz/'),
(283, 'searchprocess', 'SearchProcess', ''),
(284, 'Seekbot', 'Seekbot', 'http://www.seekbot.net/bot.html'),
(285, 'Senrigan', 'Senrigan', ''),
(286, 'Sensis Web Crawler', 'Sensis Web Crawler', 'http://www.sensis.com.au/help.do'),
(287, 'SG-Scout', 'SG-Scout', ''),
(288, 'Shagseeker', 'ShagSeeker', ''),
(289, 'Shai''Hulud', 'Shai''Hulud', ''),
(290, 'SimBot/1.0', 'Simmany Robot Ver1.0', ''),
(291, 'ssearcher100', 'Site Searcher', ''),
(292, 'Site Valet', 'Site Valet', ''),
(293, 'http://www.site-list.net', 'Site-List', 'http://www.site-list.net'),
(294, 'SiteTech-Rover', 'SiteTech-Rover', ''),
(295, '+SitiDi.net/SitiDiBot/', 'SitiDi.net/SitiDiBot', ''),
(296, 'aWapClient', 'Skymob.com', ''),
(297, 'SLCrawler', 'SLCrawler', ''),
(298, 'Sleek Spider', 'Sleek', ''),
(299, 'ESISmartSpider', 'Smart Spider', ''),
(300, 'Snooper', 'Snooper', ''),
(301, 'sohu-search', 'sohu-search', ''),
(302, 'Solbot', 'Solbot', ''),
(303, 'www.entireweb.com/speedy.html', 'Speedy Spider', ''),
(304, 'Sphere Scout', 'Sphere', ''),
(305, 'Sphider2', 'Sphider', ''),
(306, 'SpiderBot', 'SpiderBot', ''),
(307, 'spiderline', 'Spiderline Crawler', ''),
(308, 'SpiderMan', 'SpiderMan', ''),
(309, 'SpiderView', 'SpiderView(tm)', ''),
(310, 'mouse.house', 'spider_monkey', ''),
(311, 'suke', 'Suke', ''),
(312, 'suntek', 'suntek search engine', ''),
(313, 'Szukacz', 'Szukacz', 'http://www.szukacz.pl/html/RobotEnglishVersion.html'),
(314, 'T-H-U-N-D-E-R-S-T-O-N-E', 'T-H-U-N-D-E-R-S-T-O-N-E', ''),
(315, 'Black Widow', 'TACH Black Widow', ''),
(316, 'Tarantula', 'Tarantula', ''),
(317, 'tarspider', 'tarspider', ''),
(318, 'dlw3robot', 'Tcl W3 Robot', ''),
(319, 'TechBOT', 'TechBOT', ''),
(320, 'Technoratibot', 'Technorati', 'http://technorati.com/about/'),
(321, 'Templeton', 'Templeton', ''),
(322, 'teoma', 'Teoma/Ask Jeeves', 'http://sp.teoma.com/docs/teoma/about/'),
(323, 'JubiiRobot', 'The Jubii', ''),
(324, 'NorthStar', 'The NorthStar Robot', ''),
(325, 'w3index', 'The NWI Robot', ''),
(326, 'Peregrinator-Mathematics', 'The Peregrinator', ''),
(327, 'thumbshots-de-Bot', 'thumbshots-de-Bot', ''),
(328, 'TITAN', 'TITAN', ''),
(329, 'TitIn', 'TitIn', ''),
(330, 'TLSpider', 'TLSpider', ''),
(331, 'slysearch', 'Turnitin.com', 'http://www.turnitin.com/static/products_services/search_engines.html'),
(332, 'TurnitinBot/', 'TurnitinBot', ''),
(333, 'TurtleScanner', 'Turtle', 'http://www.turtle.ru/'),
(334, 'UCSD-Crawler', 'UCSD Crawl', ''),
(335, 'UMBC-memeta-Bot', 'UMBC', ''),
(336, 'Unpartisan', 'Unpartisan', 'http://www.unpartisan.com'),
(337, 'urlck', 'URL Check', ''),
(338, 'URL Spider Pro', 'URL Spider Pro', ''),
(339, 'Valkyrie', 'Valkyrie', ''),
(340, 'Verticrawl', 'Verticrawl', ''),
(341, 'Victoria', 'Victoria', ''),
(342, 'vision-search', 'vision-search', ''),
(343, 'VoilaBot', 'VoilaBot', 'http://www.voila.com/'),
(344, 'Voyager', 'Voyager', ''),
(345, 'VWbot_K', 'VWbot', ''),
(346, 'W3C-checklink', 'W3C', 'http://validator.w3.org/checklink'),
(347, 'W3C_Validator', 'W3C', 'http://validator.w3.org/'),
(348, 'W3C_CSS_Validator', 'W3C', 'http://jigsaw.w3.org/css-validator/'),
(349, 'W3M2', 'W3M2', ''),
(350, 'w3mir', 'w3mir', ''),
(351, 'w@pSpider', 'w@pSpider', ''),
(352, 'appie', 'Walhello appie', 'http://www.robotstxt.org/wc/active/html/appie.html'),
(353, 'CrawlPaper', 'WallPaper', ''),
(354, 'root', 'Web Core / Roots', ''),
(355, 'WebMoose', 'Web Moose', ''),
(356, 'WebBandit', 'WebBandit', ''),
(357, 'WebCatcher', 'WebCatcher', ''),
(358, 'Webclipping', 'Webclipping', ''),
(359, 'WebCopy', 'WebCopy', ''),
(360, 'WebFetcher', 'webfetcher', ''),
(361, 'weblayers', 'weblayers', ''),
(362, 'WebLinker', 'WebLinker', ''),
(363, 'wlm', 'Weblog Monitor', ''),
(364, 'WebQuest', 'WebQuest', ''),
(365, 'WebReaper', 'WebReaper', ''),
(366, 'webs@recruit.co.jp', 'webs', ''),
(367, 'websearchbench', 'WebSearchBench', 'http://websearchbench.cs.uni-dortmund.de/'),
(368, 'WOLP', 'WebStolperer', ''),
(369, 'webvac', 'WebVac', ''),
(370, 'webwalk', 'webwalk', ''),
(371, 'WebWalker', 'WebWalker', ''),
(372, 'WebWatch', 'WebWatch', ''),
(373, 'Wget', 'Wget', ''),
(374, 'whatUseek_winona', 'whatUseek Winona', ''),
(375, 'SurveyBot', 'Whois Source', 'http://www.whois.sc/info/webmasters/surveybot.html'),
(376, 'Hazel''s Ferret Web hopper', 'Wild Ferret Web Hopper', ''),
(377, 'Willow Internet Crawler by Twotrees', 'Willow', ''),
(378, 'WinHTTP', 'WinHTTP', ''),
(379, 'wired-digital-newsbot', 'Wired Digital', ''),
(380, 'zyborg', 'WiseNut', ''),
(381, 'OmniExplorer_Bot', 'WorldIndexer', 'http://www.omni-explorer.com'),
(382, 'WWWC', 'WWWC', ''),
(383, 'WWWeasel Robot', 'WWWeasel Robot', ''),
(384, 'wwwster', 'wwwster', ''),
(385, 'WWWWanderer', 'WWWWanderer', ''),
(386, 'TECOMAC-Crawler', 'X-Crawler', ''),
(387, 'Xenu', 'Xenu Link Sleuth', 'http://home.snafu.de/tilman/xenulink.html'),
(388, 'XGET', 'XGET', ''),
(389, 'cosmos', 'XYLEME Robot', ''),
(390, 'YahooYSMcm', 'Yahoo Publisher Network', 'http://publisher.yahoo.com/'),
(391, 'Yahoo! Slurp', 'Yahoo! Slurp', ''),
(392, 'Yahoo-Blogs', 'Yahoo-Blogs', 'http://help.yahoo.com/help/us/ysearch/crawling/crawling-02.html'),
(393, 'Yahoo-VerticalCrawler', 'Yahoo-VerticalCrawler', ''),
(394, 'YahooFeedSeeker', 'YahooFeedSeeker', 'http://my.yahoo.com/s/publishers.html'),
(395, 'Yandex', 'Yandex', 'http://www.yandex.ru/'),
(396, 'zeus', 'Zeus Internet Marketing', 'http://www.cyber-robotics.com/'),
(397, 'http://www.zorkk.com', 'Zork', 'http://www.zorkk.com');